==> message-send-1.0-sources.jar: com/bizunited/config/SmsConfig.java <==
package com.bizunited.config;

import java.util.Arrays;
import java.util.HashSet;
import java.util.ResourceBundle;
import java.util.Set;

public class SmsConfig {
	
	public static final ResourceBundle resb = ResourceBundle.getBundle("smsconfig");
	/**企业编号*/
	public static final String SPCODE = resb.getString("spCode"); 
	/**登录名*/
	public static final String LOGIN_NAME = resb.getString("loginName");
	/**密码*/
	public static final String PASSWORD = resb.getString("password");
	/**是否每天清除发送记录*/
	public static final Boolean CLEAN_SEND_LOG = Boolean.parseBoolean(resb.getString("clean_send_log_everyday"));
	/**同一内容同一手机号发送次数限制*/
	public static final Integer SAME_CONTENT_LIMIT = Integer.valueOf(resb.getString("same_content_phone_limit"));
	/**相同关键字(模版相同)同一手机号发送次数限制*/
	public static final Integer SAME_KEY_WORDS_LIMIT = Integer.valueOf(resb.getString("key_words_phone_limit"));
	/**特例手机号相同模版次数限制*/
	public static final Integer EXCEPTION_KEY_WORDS_LIMIT = Integer.valueOf(resb.getString("exception_key_words_phone_limit"));
	/**特例手机号集合*/
	public static final Set<String> EXCEPTION_PHONES = new HashSet<String>(Arrays.asList(resb.getString("exception_phones").split(","))); 
	/**就平台URL	 */
	public static final String OLD_MESSAGE_URL = resb.getString("old_message_url");
	/** 旧平台客户id*/
	public static final String OLD_CPID = resb.getString("old_cpid");
	/**旧平台渠道id	 */
	public static final String OLD_CHANNELID = resb.getString("old_channelid");
	/**就平台密码 */
	public static final String OLD_PASSWORD =  resb.getString("old_password");
}

==> message-send-1.3-sources.jar: com/bizunited/config/SmsConfig.java <==
package com.bizunited.config;

import java.util.Arrays;
import java.util.HashSet;
import java.util.ResourceBundle;
import java.util.Set;

public class SmsConfig {
	
	public static final ResourceBundle resb = ResourceBundle.getBundle("smsconfig");
	/**企业编号*/
	public static final String SPCODE = resb.getString("spCode"); 
	/**登录名*/
	public static final String LOGIN_NAME = resb.getString("loginName");
	/**密码*/
	public static final String PASSWORD = resb.getString("password");
	/**是否每天清除发送记录*/
	public static final Boolean CLEAN_SEND_LOG = Boolean.parseBoolean(resb.getString("clean_send_log_everyday"));
	/**同一内容同一手机号发送次数限制*/
	public static final Integer SAME_CONTENT_LIMIT = Integer.valueOf(resb.getString("same_content_phone_limit"));
	/**相同关键字(模版相同)同一手机号发送次数限制*/
	public static final Integer SAME_KEY_WORDS_LIMIT = Integer.valueOf(resb.getString("key_words_phone_limit"));
	/**特例手机号相同模版次数限制*/
	public static final Integer EXCEPTION_KEY_WORDS_LIMIT = Integer.valueOf(resb.getString("exception_key_words_phone_limit"));
	/**特例手机号集合*/
	public static final Set<String> EXCEPTION_PHONES = new HashSet<String>(Arrays.asList(resb.getString("exception_phones").split(","))); 
	/**就平台URL	 */
	public static final String OLD_MESSAGE_URL = resb.getString("old_message_url");
	/** 旧平台客户id*/
	public static final String OLD_CPID = resb.getString("old_cpid");
	/**旧平台渠道id	 */
	public static final String OLD_CHANNELID = resb.getString("old_channelid");
	/**就平台密码 */
	public static final String OLD_PASSWORD =  resb.getString("old_password");
	/**玄武短信用户名*/
	public static final String XW_USERNAME = resb.getString("XW_USERNAME");
	/**玄武短信用户密码*/
	public static final String XW_PASSWORD = resb.getString("XW_PASSWORD");
}
